name property
String
name
final
The name associated with the platform.
This is a final string that holds the name value.
Implementation
final String name;
The name associated with the platform.
This is a final string that holds the name value.
final String name;