closeAndPop property
Future<void> Function()
closeAndPop
final
Closes the active native flow and returns control to Flutter.
Implementation
final Future<void> Function() closeAndPop;
Closes the active native flow and returns control to Flutter.
final Future<void> Function() closeAndPop;