flutter_smartface_enroller library Overview Biometric Flows

Enrollment APIs focused on flows without immediate server push.

Use FlutterSmartfaceEnrollerPlatform when you need to prepare enrollment without pushing to the backend or when you need descriptor-oriented helper APIs.

For the broader biometric API that also includes identification and full enrollment widgets, see flutter_smartface_mobile.

Classes

FlutterSmartfaceEnrollerPlatform
An abstract class that extends PlatformInterface to define the platform-specific implementation for the Flutter Smartface plugin.