SmartfaceHostedFlow class

Hosted flow bridge for presenting native Smartface identification flows

This is a convenience wrapper class that provides backward compatibility. It delegates to the modular IdentificationFlow and EnrollmentFlow classes.

Constructors

SmartfaceHostedFlow()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

enroll({EnrollmentCallback? onComplete, EnrollmentProgressCallback? onProgress, EnrollmentFlowOptions? options}) → Future<void>
Simplified single callback API for enrollment (similar to MAUI EnrollmentFlow.Run)
identify({IdentificationCallback? onComplete, IdentificationFlowOptions? options}) → Future<void>
Simplified single callback API (similar to MAUI IdentificationFlow.Run)