getSmartfaceModelMajorVersion method

Future<String> getSmartfaceModelMajorVersion()

Retrieves the Smartface model major version from the native platform.

Returns a String containing the model major version or 'not found' if the platform does not expose it.

Implementation

Future<String> getSmartfaceModelMajorVersion() async {
  final response = await invokeNativeMethod(
    'SmartfaceLicense.getSmartfaceModelMajorVersion',
  );

  if (response.isLeft()) {
    return 'not found';
  }

  return response.asRight.toString();
}