installProduct method
Installs a product using the provided product item details.
This method invokes the native method SmartfaceLicense.installProduct
with the given product item details.
Returns a Future that completes with an Either containing a String
on failure or a dynamic value on success.
Parameters:
productItem: A map containing the details of the product to be installed.
Implementation
Future<Either<String, dynamic>> installProduct({
required Map<dynamic, dynamic> productItem,
}) async {
return install(id: productItem['id'].toString());
}