FlutterSmartfacePlatformCameraController class
Constructors
-
FlutterSmartfacePlatformCameraController({required Future<void> switchCamera(), required Future<void> closeAndPop(), Future<void> setLivenessSecurityLevel(double)?})
-
Creates a controller that proxies camera commands to the native side.
Properties
-
closeAndPop
→ Future<void> Function()
-
Closes the active native flow and returns control to Flutter.
final
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
setLivenessSecurityLevel
→ Future<void> Function(double)?
-
Updates the liveness security level while the flow is active.
final
-
switchCamera
→ Future<void> Function()
-
Switches between the available cameras.
final
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Operators
-
operator ==(Object other)
→ bool
-
The equality operator.
inherited